/*
 * This file is part of INAV Project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this file,
 * You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * Alternatively, the contents of this file may be used under the terms
 * of the GNU General Public License Version 3, as described below:
 *
 * This file is free software: you may copy, redistribute and/or modify
 * it under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 *
 * This file is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 * Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
 */

// NB: I use PC12 for dvr so keep it mind
#pragma once

#define TARGET_BOARD_IDENTIFIER "SKST7HD"
#define USBD_PRODUCT_STRING     "SKYSTARSF7HD"

// Betaflight
// resource LED 1 C15
// resource LED 2 C14
#define LED0                    PC15
#define LED1                    PC14

// Betaflight
// resource BEEPER 1 B02
#define BEEPER                  PB2

// Betaflight
//beeper_inversion = ON
#define BEEPER_INVERTED 

/*
 * Buses
 */
 /*
Betaflight
resource SPI_SCK 1 A05
resource SPI_SCK 2 B13
resource SPI_SCK 3 C10
resource SPI_SCK 4 NONE
resource SPI_MISO 1 A06
resource SPI_MISO 2 B14
resource SPI_MISO 3 C11
resource SPI_MISO 4 NONE
resource SPI_MOSI 1 A07
resource SPI_MOSI 2 B15
resource SPI_MOSI 3 B05
resource SPI_MOSI 4 NONE
*/
#define USE_SPI
#define USE_SPI_DEVICE_1
#define SPI1_SCK_PIN            PA5
#define SPI1_MISO_PIN           PA6
#define SPI1_MOSI_PIN           PA7

#define USE_SPI_DEVICE_2
#define SPI2_SCK_PIN            PB13
#define SPI2_MISO_PIN           PB14
#define SPI2_MOSI_PIN           PB15

#define USE_SPI_DEVICE_3
#define SPI3_SCK_PIN            PC10
#define SPI3_MISO_PIN           PC11 
#define SPI3_MOSI_PIN           PB5

/*
Betaflight
resource I2C_SCL 1 B08
resource I2C_SDA 1 B09
*/
#define USE_I2C
#define USE_I2C_DEVICE_1
#define I2C1_SCL                PB8      
#define I2C1_SDA                PB9 

/*
 * Serial Ports
 */

/*
Betaflight
resource SERIAL_TX 1 B06
resource SERIAL_TX 2 A02
resource SERIAL_TX 3 B10
resource SERIAL_TX 4 A00
resource SERIAL_TX 5 NONE
resource SERIAL_TX 6 C06
resource SERIAL_RX 1 B07
resource SERIAL_RX 2 A03
resource SERIAL_RX 3 B11
resource SERIAL_RX 4 A01
resource SERIAL_RX 5 D02
resource SERIAL_RX 6 C07
*/
#define USE_VCP

#define USE_UART1
#define UART1_TX_PIN            PB6
#define UART1_RX_PIN            PB7

#define USE_UART2
#define UART2_TX_PIN            PA2
#define UART2_RX_PIN            PA3

#define USE_UART3
#define UART3_TX_PIN            PB10
#define UART3_RX_PIN            PB11

#define USE_UART4
#define UART4_TX_PIN            PA0
#define UART4_RX_PIN            PA1

// use for dvr so just skip it
//#define USE_UART5
//#define UART5_TX_PIN            PC12 =>pinio
//#define UART5_RX_PIN            PD2

#define USE_UART6   
#define UART6_TX_PIN            PC6  
#define UART6_RX_PIN            PC7  

//vcp, u1-6 (w/o u5)
#define SERIAL_PORT_COUNT       6 

/*
 * Gyro
 */
#define USE_EXTI
#define USE_MPU_DATA_READY_SIGNAL

/*
Betaflight
set gyro_1_bustype = SPI
set gyro_1_spibus = 1
set gyro_1_i2cBus = 0
set gyro_1_i2c_address = 0
set gyro_1_sensor_align = CW180
set gyro_1_align_roll = 0
set gyro_1_align_pitch = 0
set gyro_1_align_yaw = 1800

set align_board_roll = 0
set align_board_pitch = 0
set align_board_yaw = 90 -== в cli

resource GYRO_EXTI 1 C04
resource GYRO_CS 1 A04

in inav.config.cli
align_gyro = CW180
align_acc = CW180
align_board_yaw = 900

*/
// MPU6000
#define USE_IMU_MPU6000
#define IMU_MPU6000_ALIGN       CW180_DEG
#define MPU6000_SPI_BUS         BUS_SPI1
#define MPU6000_EXTI_PIN        PC4
#define MPU6000_CS_PIN          PA4

/*
Betaflight
resource FLASH_CS 1 A15
set blackbox_device = SPIFLASH
set flash_spi_bus = 3
set cc2500_spi_chip_detect = ON

*/
/*
 * Blackbox Onboard Flash
 */
#define USE_FLASHFS
#define USE_FLASH_M25P16
#define M25P16_CS_PIN           PA15
#define M25P16_SPI_BUS          BUS_SPI3

/*
Betaflight
set max7456_spi_bus = 2
resource OSD_CS 1 B12
*/
/*
 * OSD
 */
#define USE_OSD
#define USE_MAX7456
#define MAX7456_SPI_BUS         BUS_SPI2
#define MAX7456_CS_PIN          PB12

/*
Betaflight
resource BARO_CS 1 B01
set baro_bustype = SPI
set baro_spi_device = 2
*/
/*
 * Baro
 */
#define USE_BARO

#define USE_BARO_BMP280
#define USE_BARO_SPI_BMP280
#define BMP280_SPI_BUS        BUS_SPI2
#define BMP280_CS_PIN         PB1

/*
 * Mag
 */
#define USE_MAG
#define MAG_I2C_BUS             BUS_I2C1
#define USE_MAG_HMC5883
#define USE_MAG_QMC5883
#define USE_MAG_IST8310
#define USE_MAG_MAG3110
#define USE_MAG_LIS3MDL

/*
Betaflight
dma ADC 2 0
# ADC 2: DMA2 Stream 2 Channel 1

resource ADC_BATT 1 C01
resource ADC_RSSI 1 C02
resource ADC_CURR 1 C03
*/
/*
 * ADC
 */
#define ADC_INSTANCE                ADC1
#define ADC1_DMA_STREAM             DMA2_Stream0
#define USE_ADC
#define ADC_CHANNEL_1_PIN               PC1
#define ADC_CHANNEL_2_PIN               PC2
#define ADC_CHANNEL_3_PIN               PC3
#define VBAT_ADC_CHANNEL                ADC_CHN_1
#define RSSI_ADC_CHANNEL                ADC_CHN_2
#define CURRENT_METER_ADC_CHANNEL       ADC_CHN_3

// Betaflight
// resource LED_STRIP 1 B03
/*
 * LED Strip
 */
#define USE_LED_STRIP
#define WS2811_PIN                      PB3

/*
Betaflight with my own dvr
set pinio_config = 129,129,1,1
set pinio_box = 0,0,255,255

in target.c
pinio_box1 = 0
pinio_box2 = 0 my own dvr
*/

#define USE_PINIO
#define USE_PINIOBOX
#define PINIO1_PIN                  PB0  
#define PINIO1_FLAGS                PINIO_FLAGS_INVERTED
// my own dvr
#define PINIO2_PIN                  PC12 
#define PINIO2_FLAGS                PINIO_FLAGS_INVERTED

/*
Betaflight
set serialrx_provider = SBUS
set serialrx_inverted = OFF
set serialrx_halfduplex = OFF
set serial_update_rate_hz = 100
*/
/*
 * Defaults
 */
#define ENABLE_BLACKBOX_LOGGING_ON_SPIFLASH_BY_DEFAULT
#define SERIALRX_UART                   SERIAL_PORT_USART1
#define DEFAULT_RX_TYPE                 RX_TYPE_SERIAL
#define SERIALRX_PROVIDER               SERIALRX_SBUS

#define DEFAULT_FEATURES            (FEATURE_TX_PROF_SEL | FEATURE_CURRENT_METER | FEATURE_TELEMETRY | FEATURE_VBAT | FEATURE_OSD | FEATURE_BLACKBOX)


#define USE_SERIAL_4WAY_BLHELI_INTERFACE
#define MAX_PWM_OUTPUT_PORTS            4
#define USE_DSHOT
#define USE_ESC_SENSOR
#define USE_SERIALSHOT

/*** Used pins ***/
#define TARGET_IO_PORTA         0xffff
#define TARGET_IO_PORTB         0xffff
#define TARGET_IO_PORTC         0xffff
#define TARGET_IO_PORTD         0xffff
#define TARGET_IO_PORTE         0xffff
